@@ -6,12 +6,13 @@
 /**
  * @file api/v1/site/index.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2023 Simon Fraser University
+ * Copyright (c) 2023 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup api_v1_site
+ *
  * @brief Handle API requests for the site object.
  */
-import('lib.pkp.api.v1.site.PKPSiteHandler');
-return new PKPSiteHandler();
+
+return new \PKP\handler\APIHandler(new \PKP\API\v1\site\PKPSiteController());
